# coding: utf-8

class AuditLogRouter(object):

    def db_for_read(self, model, **hints):
        """
        Attempts to read auth models go to auth_db.
        """
        if model._meta.app_label == 'auditlog':
            return 'auditlog_db'
        return None

    def db_for_write(self, model, **hints):
        """
        Attempts to write auth models go to auth_db.
        """
        if model._meta.app_label == 'auditlog':
            return 'auditlog_db'
        return None

    def allow_relation(self, obj1, obj2, **hints):
        """
        Allow relations if a model in the auth app is involved.
        """
        if obj1._meta.app_label == 'auditlog' or \
           obj2._meta.app_label == 'auditlog':
           return True
        return None

    def allow_migrate(self, db, app_label, model_name=None, **hints):
        """
        Make sure the auth app only appears in the 'auth_db'
        database.
        """
        if app_label == 'auditlog':
            return db == 'auditlog_db'
        return None


# Generated by Django 2.2.5 on 2019-09-12 15:10

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AuditLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data_e_hora', models.DateTimeField(blank=True, default=django.utils.timezone.now, null=True)),
                ('atividade', models.CharField(max_length=256)),
                ('usuario', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Log de Auditoria',
                'verbose_name_plural': 'Logs de Auditoria',
                'ordering': ['-data_e_hora'],
            },
        ),
    ]



from django.contrib import admin

from auditlog.models import *

class AuditLogAdmin(admin.ModelAdmin):
    list_display = ['usuario','atividade','data_e_hora']
    list_filter = [
        'usuario'
    ]
    search_fields = [
        'usuario',
    ]

admin.site.register(AuditLog, AuditLogAdmin)



# Generated by Django 2.2.5 on 2019-09-18 01:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auditlog', '0002_auto_20190913_0219'),
    ]

    operations = [
        migrations.AddField(
            model_name='auditlog',
            name='objeto',
            field=models.CharField(default='algum objeto', max_length=256),
        ),
    ]



#coding:utf-8

from django.db import models
from django.utils import timezone
from django.contrib.auth.models import User

class AuditLog(models.Model):
    data_e_hora = models.DateTimeField(default=timezone.now, blank=True, null=True)
    atividade = models.CharField(max_length=256)
    #usuario = models.ForeignKey(User, on_delete=models.CASCADE)
    usuario = models.CharField(max_length=256)
    objeto = models.CharField(max_length=256, default='algum objeto')

    class Meta:
        app_label = 'auditlog'
        verbose_name = 'Log de Auditoria'
        verbose_name_plural = 'Logs de Auditoria'
        ordering = ['-data_e_hora']


# Generated by Django 2.2.5 on 2019-09-13 02:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auditlog', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='auditlog',
            name='usuario',
            field=models.CharField(max_length=256),
        ),
    ]



#coding: utf-8

import django.dispatch
from auditlog.models import AuditLog

import traceback
import sys

def registra_log(sender, **kwargs):
	try:
		instance = kwargs['instance']
		user = kwargs['user']
		acao = kwargs['acao']
		if instance is not None:
			if acao == 'create':
				atividade = f'Criou o objeto: {instance.__class__}: pk: {instance.pk}'
			elif acao == 'update':
				atividade = f'Alterou o objeto {instance.__class__}|Propriedades: {instance.__dict__}'
			elif acao == 'delete':
				atividade = f'Deletou o objeto {instance.__class__}: pk: {instance.pk}'
			AuditLog.objects.create(usuario=user.username, atividade=atividade, objeto=instance.__class__)
		else:
			print('AuditLog Error: Vc precisa indicar a instância da classe para o AuditLog')
	except:
		print("Error no AuditLog")
		traceback.print_exc(file=sys.stdout)

AuditLogDispatcher = django.dispatch.Signal(providing_args=['user','instance','acao'])
AuditLogDispatcher.connect(registra_log)
